@@ -160,7 +160,7 @@ package MetaTrans::Base;
 
 use strict;
 use warnings;
-use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS);
+use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS %ENV);
 use Exporter;
 use MetaTrans::Languages qw(get_lang_by_code is_known_lang);
 
@@ -171,7 +171,7 @@ use HTML::Entities;
 use LWP::UserAgent;
 use HTTP::Response;
 
-$VERSION     = do { my @r = (q$Revision: 1.2 $ =~ /\d+/g); sprintf "%d."."%02d", @r };
+$VERSION     = do { my @r = (q$Revision: 1.3 $ =~ /\d+/g); sprintf "%d."."%02d", @r };
 @ISA         = qw(Exporter);
 @EXPORT_OK   = qw(is_exact_match is_match_at_start is_match_expr is_match_words
     convert_to_utf8 M_EXACT M_START M_EXPR M_WORDS M_ALL);
@@ -819,6 +819,7 @@ sub translate
     }
 
     my $ua = new LWP::UserAgent;
+    $ua->cookie_jar({ file => "$ENV{HOME}/.metatrans.cookies.txt" });
     $ua->timeout($self->{timeout});
 
     # strip blanks
